NetMessage class final

A payload received from the remote end of a connection.

Constructors

NetMessage(Channel channel, Uint8List payload)

Properties

channel Channel
final
hashCode int
The hash code for this object.
no setterinherited
payload Uint8List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited