WebSocketWireServer class final

A WebSocket server producing WireConnections. dart:io only.

Properties

connections Stream<WireConnection>
Accepted connections. Hand each to a SessionListener.
no setter
hashCode int
The hash code for this object.
no setterinherited
port int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bind(Object address, int port) Future<WebSocketWireServer>